[git] GnuPG - branch, master, updated. gnupg-2.1.20-101-g5c8fe54

by NIIBE Yutaka cvs at cvs.gnupg.org
Fri Apr 28 03:08:18 CEST 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GNU Privacy Guard".

The branch, master has been updated
       via  5c8fe5480964c282540c051b538e812851988422 (commit)
      from  97a2394ecafaa6f58e4a1f70ecfd04408dc15606 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 5c8fe5480964c282540c051b538e812851988422
Author: NIIBE Yutaka <gniibe at fsij.org>
Date:   Fri Apr 28 10:06:33 2017 +0900

    Spelling fixes in docs and comments.
    
    --
    
    In addition, fix trailing spaces in tests/inittests.
    
    GnuPG-bug-id: 3121
    Reported-by: ka7 (klemens)
    Signed-off-by: NIIBE Yutaka <gniibe at fsij.org>

diff --git a/agent/call-pinentry.c b/agent/call-pinentry.c
index 6524cb1..1ff4059 100644
--- a/agent/call-pinentry.c
+++ b/agent/call-pinentry.c
@@ -114,7 +114,7 @@ initialize_module_call_pinentry (void)
 
 
 
-/* This function may be called to print infromation pertaining to the
+/* This function may be called to print information pertaining to the
    current state of this module to the log. */
 void
 agent_query_dump_state (void)
@@ -318,7 +318,7 @@ start_pinentry (ctrl_t ctrl)
       log_error ("error flushing pending output: %s\n", strerror (errno));
       /* At least Windows XP fails here with EBADF.  According to docs
          and Wine an fflush(NULL) is the same as _flushall.  However
-         the Wine implementaion does not flush stdin,stdout and stderr
+         the Wine implementation does not flush stdin,stdout and stderr
          - see above.  Let's try to ignore the error. */
 #ifndef HAVE_W32_SYSTEM
       return unlock_pinentry (tmperr);
@@ -911,7 +911,7 @@ pinentry_status_cb (void *opaque, const char *line)
 }
 
 
-/* Build a SETDESC command line.  This is a dedicated funcion so that
+/* Build a SETDESC command line.  This is a dedicated function so that
  * it can remove control characters which are not supported by the
  * current Pinentry.  */
 static void
diff --git a/agent/call-scd.c b/agent/call-scd.c
index 09ec4fd..cf61a35 100644
--- a/agent/call-scd.c
+++ b/agent/call-scd.c
@@ -145,7 +145,7 @@ initialize_module_call_scd (void)
 }
 
 
-/* This function may be called to print infromation pertaining to the
+/* This function may be called to print information pertaining to the
    current state of this module to the log. */
 void
 agent_scd_dump_state (void)
@@ -306,7 +306,7 @@ start_scd (ctrl_t ctrl)
       log_error ("error flushing pending output: %s\n", strerror (errno));
       /* At least Windows XP fails here with EBADF.  According to docs
          and Wine an fflush(NULL) is the same as _flushall.  However
-         the Wime implementaion does not flush stdin,stdout and stderr
+         the Wime implementation does not flush stdin,stdout and stderr
          - see above.  Lets try to ignore the error. */
 #ifndef HAVE_W32_SYSTEM
       goto leave;
diff --git a/agent/command-ssh.c b/agent/command-ssh.c
index fdde0fb..57e2e42 100644
--- a/agent/command-ssh.c
+++ b/agent/command-ssh.c
@@ -2112,7 +2112,7 @@ ssh_receive_key (estream_t stream, gcry_sexp_t *key_new, int secret,
        *   string	private_key
        *
        * Note that the private key is the concatenation of the private
-       * key with the public key.  Thus theres are 64 bytes; however
+       * key with the public key.  Thus there's are 64 bytes; however
        * we only want the real 32 byte private key - Libgcrypt expects
        * this.
        */
@@ -3650,7 +3650,7 @@ start_command_handler_ssh (ctrl_t ctrl, gnupg_fd_t sock_client)
   /* Main processing loop. */
   while ( !ssh_request_process (ctrl, stream_sock) )
     {
-      /* Check wether we have reached EOF before trying to read
+      /* Check whether we have reached EOF before trying to read
 	 another request.  */
       int c;
 
diff --git a/agent/findkey.c b/agent/findkey.c
index f3c8ca9..b24d8f1 100644
--- a/agent/findkey.c
+++ b/agent/findkey.c
@@ -1264,7 +1264,7 @@ agent_public_key_from_file (ctrl_t ctrl,
   /* FIXME: The following thing is pretty ugly code; we should
      investigate how to make it cleaner.  Probably code to handle
      canonical S-expressions in a memory buffer is better suited for
-     such a task.  After all that is what we do in protect.c.  Neeed
+     such a task.  After all that is what we do in protect.c.  Need
      to find common patterns and write a straightformward API to use
      them.  */
   assert (sizeof (size_t) <= sizeof (void*));
diff --git a/agent/pkdecrypt.c b/agent/pkdecrypt.c
index f1023b4..46697ba 100644
--- a/agent/pkdecrypt.c
+++ b/agent/pkdecrypt.c
@@ -1,4 +1,4 @@
-/* pkdecrypt.c - public key decryption (well, acually using a secret key)
+/* pkdecrypt.c - public key decryption (well, actually using a secret key)
  *	Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
diff --git a/agent/pksign.c b/agent/pksign.c
index f0b10e6..8faf4a4 100644
--- a/agent/pksign.c
+++ b/agent/pksign.c
@@ -190,7 +190,7 @@ do_encode_dsa (const byte *md, size_t mdlen, int pkalgo, gcry_sexp_t pkey,
     }
 
   /* ECDSA 521 is special has it is larger than the largest hash
-     we have (SHA-512).  Thus we chnage the size for further
+     we have (SHA-512).  Thus we change the size for further
      processing to 512.  */
   if (pkalgo == GCRY_PK_ECDSA && qbits > 512)
     qbits = 512;
diff --git a/agent/trustlist.c b/agent/trustlist.c
index 5554485..af177b2 100644
--- a/agent/trustlist.c
+++ b/agent/trustlist.c
@@ -612,7 +612,7 @@ agent_marktrusted (ctrl_t ctrl, const char *name, const char *fpr, int flag)
 
   /* Check whether we are at all allowed to modify the trustlist.
      This is useful so that the trustlist may be a symlink to a global
-     trustlist with only admin priviliges to modify it.  Of course
+     trustlist with only admin privileges to modify it.  Of course
      this is not a secure way of denying access, but it avoids the
      usual clicking on an Okay button most users are used to. */
   fname = make_filename_try (gnupg_homedir (), "trustlist.txt", NULL);
diff --git a/build-aux/texinfo.tex b/build-aux/texinfo.tex
index a181898..5a17f97 100644
--- a/build-aux/texinfo.tex
+++ b/build-aux/texinfo.tex
@@ -415,7 +415,7 @@
 \def\argremovecomment#1\comment#2\ArgTerm{\argremovec #1\c\ArgTerm}
 \def\argremovec#1\c#2\ArgTerm{\argcheckspaces#1\^^M\ArgTerm}
 
-% Each occurence of `\^^M' or `<space>\^^M' is replaced by a single space.
+% Each occurrence of `\^^M' or `<space>\^^M' is replaced by a single space.
 %
 % \argremovec might leave us with trailing space, e.g.,
 %    @end itemize  @c foo
@@ -440,7 +440,7 @@
 % to get _exactly_ the rest of the line, we had to prevent such situation.
 % We prepended an \empty token at the very beginning and we expand it now,
 % just before passing the control to \argtorun.
-% (Similarily, we have to think about #3 of \argcheckspacesY above: it is
+% (Similarly, we have to think about #3 of \argcheckspacesY above: it is
 % either the null string, or it ends with \^^M---thus there is no danger
 % that a pair of braces would be stripped.
 %
@@ -497,7 +497,7 @@
 % used to check whether the current environment is the one expected.
 %
 % Non-false conditionals (@iftex, @ifset) don't fit into this, so they
-% are not treated as enviroments; they don't open a group.  (The
+% are not treated as environments; they don't open a group.  (The
 % implementation of @end takes care not to call \endgroup in this
 % special case.)
 
@@ -520,7 +520,7 @@
   \fi
 }
 
-% Evironment mismatch, #1 expected:
+% Environment mismatch, #1 expected:
 \def\badenverr{%
   \errhelp = \EMsimple
   \errmessage{This command can appear only \inenvironment\temp,
@@ -7034,7 +7034,7 @@ end
 % In case a @footnote appears in a vbox, save the footnote text and create
 % the real \insert just after the vbox finished.  Otherwise, the insertion
 % would be lost.
-% Similarily, if a @footnote appears inside an alignment, save the footnote
+% Similarly, if a @footnote appears inside an alignment, save the footnote
 % text to a box and make the \insert when a row of the table is finished.
 % And the same can be done for other insert classes.  --kasal, 16nov03.
 
diff --git a/common/ChangeLog-2011.include b/common/ChangeLog-2011.include
index b5a9a5e..b9ca861 100644
--- a/common/ChangeLog-2011.include
+++ b/common/ChangeLog-2011.include
@@ -250,7 +250,7 @@
 2001-12-19  Werner Koch  <wk at gnupg.org>
 
 	* util.h [CYGWIN32]: Allow this as an alias for MINGW32. Include
-	stdarg.h becuase we use the va_list type.  By Disastry.
+	stdarg.h because we use the va_list type.  By Disastry.
 
 2001-09-28  Werner Koch  <wk at gnupg.org>
 
diff --git a/common/audit.c b/common/audit.c
index 7d545a3..179bf72 100644
--- a/common/audit.c
+++ b/common/audit.c
@@ -716,7 +716,7 @@ list_cert (audit_ctx_t ctx, ksba_cert_t cert, int with_subj)
 
 
 /* List the chain of certificates from STARTITEM up to STOPEVENT.  The
-   certifcates are written out as comments.  */
+   certificates are written out as comments.  */
 static void
 list_certchain (audit_ctx_t ctx, log_item_t startitem, audit_event_t stopevent)
 {
diff --git a/common/call-gpg.c b/common/call-gpg.c
index d42325a..c1472e9 100644
--- a/common/call-gpg.c
+++ b/common/call-gpg.c
@@ -75,7 +75,7 @@ start_gpg (ctrl_t ctrl, const char *gpg_program, strlist_t gpg_arguments,
       return err;
     }
 
-  /* The first time we are used, intialize the gpg_program variable.  */
+  /* The first time we are used, initialize the gpg_program variable.  */
   if ( !gpg_program || !*gpg_program )
     gpg_program = gnupg_module_name (GNUPG_MODULE_NAME_GPG);
 
diff --git a/common/dotlock.c b/common/dotlock.c
index cbbd0f3..5227bb6 100644
--- a/common/dotlock.c
+++ b/common/dotlock.c
@@ -332,7 +332,7 @@
 # endif
 #endif
 
-/* In GnuPG we use wrappers around the malloc fucntions.  If they are
+/* In GnuPG we use wrappers around the malloc functions.  If they are
    not defined we assume that this code is used outside of GnuPG and
    fall back to the regular malloc functions.  */
 #ifndef xtrymalloc
diff --git a/common/exechelp.h b/common/exechelp.h
index 6f2653b..2b40ba0 100644
--- a/common/exechelp.h
+++ b/common/exechelp.h
@@ -115,7 +115,7 @@ gpg_error_t gnupg_create_pipe (int filedes[2]);
    GNUPG_SPAWN_RUN_ASFW
           On W32 (but not on W32CE) run AllowSetForegroundWindow for
           the child.  Note that due to unknown problems this actually
-          allows SetForegroundWindow for all childs of this process.
+          allows SetForegroundWindow for all children of this process.
 
  */
 gpg_error_t
@@ -162,7 +162,7 @@ gpg_error_t gnupg_spawn_process_fd (const char *pgmname,
 
    Other error codes may be returned as well.  Unless otherwise noted,
    -1 will be stored at R_EXITCODE.  R_EXITCODE may be passed as NULL
-   if the exit code is not required (in that case an error messge will
+   if the exit code is not required (in that case an error message will
    be printed).  Note that under Windows PID is not the process id but
    the handle of the process.  */
 gpg_error_t gnupg_wait_process (const char *pgmname, pid_t pid, int hang,
diff --git a/common/exectool.c b/common/exectool.c
index c9e0020..3458de4 100644
--- a/common/exectool.c
+++ b/common/exectool.c
@@ -430,7 +430,7 @@ gnupg_exec_tool_stream (const char *pgmname, const char *argv[],
 
   /* Now read as long as we have something to poll.  We continue
      reading even after EOF or error on stdout so that we get the
-     other error messages or remaining outut.  */
+     other error messages or remaining output.  */
   while (! (fds[1].ignore && fds[2].ignore))
     {
       count = es_poll (fds, DIM(fds), -1);
diff --git a/common/init.h b/common/init.h
index 28462a7..3a5beca 100644
--- a/common/init.h
+++ b/common/init.h
@@ -1,4 +1,4 @@
-/* init.h - Definitions for init fucntions.
+/* init.h - Definitions for init functions.
  * Copyright (C) 2007, 2012 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
diff --git a/common/openpgp-oid.c b/common/openpgp-oid.c
index e7c68f2..d800e7d 100644
--- a/common/openpgp-oid.c
+++ b/common/openpgp-oid.c
@@ -141,7 +141,7 @@ openpgp_oid_from_str (const char *string, gcry_mpi_t *r_mpi)
     if (arcno == 1)
       {
         if (val > 2)
-          break; /* Not allowed, error catched below.  */
+          break; /* Not allowed, error caught below.  */
         val1 = val;
       }
     else if (arcno == 2)
diff --git a/common/recsel.c b/common/recsel.c
index 66c1c5e..b2b302b 100644
--- a/common/recsel.c
+++ b/common/recsel.c
@@ -602,7 +602,7 @@ recsel_select (recsel_expr_t selector,
 
       if (result)
         {
-          /* This expression evaluated to true.  See wether there are
+          /* This expression evaluated to true.  See whether there are
              remaining expressions in this conjunction.  */
           if (!se->next || se->next->disjun)
             break; /* All expressions are true.  Return True.  */
diff --git a/common/sexputil.c b/common/sexputil.c
index a8dc1a5..f30790a 100644
--- a/common/sexputil.c
+++ b/common/sexputil.c
@@ -29,7 +29,7 @@
  */
 
 /* This file implements a few utility functions useful when working
-   with canonical encrypted S-expresions (i.e. not the S-exprssion
+   with canonical encrypted S-expressions (i.e. not the S-exprssion
    objects from libgcrypt).  */
 
 #include <config.h>
@@ -266,7 +266,7 @@ cmp_simple_canon_sexp (const unsigned char *a_orig,
 /* Create a simple S-expression from the hex string at LINE.  Returns
    a newly allocated buffer with that canonical encoded S-expression
    or NULL in case of an error.  On return the number of characters
-   scanned in LINE will be stored at NSCANNED.  This fucntions stops
+   scanned in LINE will be stored at NSCANNED.  This functions stops
    converting at the first character not representing a hexdigit. Odd
    numbers of hex digits are allowed; a leading zero is then
    assumed. If no characters have been found, NULL is returned.*/
diff --git a/common/simple-pwquery.h b/common/simple-pwquery.h
index 772aa39..9bbc53f 100644
--- a/common/simple-pwquery.h
+++ b/common/simple-pwquery.h
@@ -1,4 +1,4 @@
-/* simple-pwquery.c - A simple password query cleint for gpg-agent
+/* simple-pwquery.c - A simple password query client for gpg-agent
  *	Copyright (C) 2002 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
diff --git a/common/sysutils.c b/common/sysutils.c
index a796677..ea0acdb 100644
--- a/common/sysutils.c
+++ b/common/sysutils.c
@@ -416,7 +416,7 @@ translate_sys2libc_fd_int (int fd, int for_write)
 /* Check whether FNAME has the form "-&nnnn", where N is a non-zero
  * number.  Returns this number or -1 if it is not the case.  If the
  * caller wants to use the file descriptor for writing FOR_WRITE shall
- * be set to 1.  If NOTRANSLATE is set the Windows spefic mapping is
+ * be set to 1.  If NOTRANSLATE is set the Windows specific mapping is
  * not done. */
 int
 check_special_filename (const char *fname, int for_write, int notranslate)
diff --git a/common/t-session-env.c b/common/t-session-env.c
index aa9d596..e2b942c 100644
--- a/common/t-session-env.c
+++ b/common/t-session-env.c
@@ -103,7 +103,7 @@ test_all (void)
   if (gpg_err_code (err) != GPG_ERR_INV_VALUE)
     fail (err);
 
-  /* Delete some nonexistant variables.  */
+  /* Delete some nonexistent variables.  */
   err = session_env_putenv (se, "A");
   if (err)
     fail (err);
diff --git a/configure.ac b/configure.ac
index 494e444..9395fb8 100644
--- a/configure.ac
+++ b/configure.ac
@@ -857,7 +857,7 @@ AC_SUBST(LIBUSB_LIBS)
 AC_SUBST(LIBUSB_CPPFLAGS)
 
 #
-# Check wether it is necessary to link against libdl.
+# Check whether it is necessary to link against libdl.
 # (For example to load libpcsclite)
 #
 gnupg_dlopen_save_libs="$LIBS"
@@ -1393,7 +1393,7 @@ AC_CHECK_TYPES([struct sigaction, sigset_t],,,[#include <signal.h>])
 
 # Dirmngr requires mmap on Unix systems.
 if test $ac_cv_func_mmap != yes -a $mmap_needed = yes; then
-  AC_MSG_ERROR([[Sorry, the current implemenation requires mmap.]])
+  AC_MSG_ERROR([[Sorry, the current implementation requires mmap.]])
 fi
 
 
@@ -1570,7 +1570,7 @@ if test "$GCC" = yes; then
     mycflags=
     mycflags_save=$CFLAGS
 
-    # Check whether gcc does not emit a diagnositc for unknow -Wno-*
+    # Check whether gcc does not emit a diagnositc for unknown -Wno-*
     # options.  This is the case for gcc >= 4.6
     AC_MSG_CHECKING([if gcc ignores unknown -Wno-* options])
     AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[
diff --git a/dirmngr/certcache.c b/dirmngr/certcache.c
index c3f3427..b4e5381 100644
--- a/dirmngr/certcache.c
+++ b/dirmngr/certcache.c
@@ -97,7 +97,7 @@ static unsigned int total_nonperm_certificates;
 
 #ifdef HAVE_W32_SYSTEM
 /* We load some functions dynamically.  Provide typedefs for tehse
- * fucntions.  */
+ * functions.  */
 typedef HCERTSTORE (WINAPI *CERTOPENSYSTEMSTORE)
   (HCRYPTPROV hProv, LPCSTR szSubsystemProtocol);
 typedef PCCERT_CONTEXT (WINAPI *CERTENUMCERTIFICATESINSTORE)
diff --git a/dirmngr/dns-stuff.c b/dirmngr/dns-stuff.c
index 0635115..a6c14cd 100644
--- a/dirmngr/dns-stuff.c
+++ b/dirmngr/dns-stuff.c
@@ -526,7 +526,7 @@ libdns_init (void)
           /* No DNS resolution type found in the list.  This might be
            * due to systemd based systems which allow for custom
            * keywords which are not known to us and thus we do not
-           * know whether DNS is wanted or not.  Becuase DNS is
+           * know whether DNS is wanted or not.  Because DNS is
            * important for our infrastructure, we forcefully append
            * DNS to the end of the list.  */
           if (strlen (ld.resolv_conf->lookup)+2 < sizeof ld.resolv_conf->lookup)
diff --git a/dirmngr/dns-stuff.h b/dirmngr/dns-stuff.h
index adb0b80..612b2e5 100644
--- a/dirmngr/dns-stuff.h
+++ b/dirmngr/dns-stuff.h
@@ -154,7 +154,7 @@ int is_onion_address (const char *name);
 /* Get the canonical name for NAME.  */
 gpg_error_t get_dns_cname (const char *name, char **r_cname);
 
-/* Return a CERT record or an arbitray RR.  */
+/* Return a CERT record or an arbitrary RR.  */
 gpg_error_t get_dns_cert (const char *name, int want_certtype,
                           void **r_key, size_t *r_keylen,
                           unsigned char **r_fpr, size_t *r_fprlen,
diff --git a/dirmngr/dns.c b/dirmngr/dns.c
index 5b8f14f..c660cf5 100644
--- a/dirmngr/dns.c
+++ b/dirmngr/dns.c
@@ -4263,7 +4263,7 @@ size_t dns_txt_print(void *_dst, size_t lim, struct dns_txt *txt) {
 
 
 /* Some of the function pointers of DNS_RRTYPES are initialized with
- * slighlly different fucntions, thus we can't use prototypes.  */
+ * slighlly different functions, thus we can't use prototypes.  */
 DNS_PRAGMA_PUSH
 #if __clang__
 #pragma clang diagnostic ignored "-Wstrict-prototypes"
diff --git a/dirmngr/http.c b/dirmngr/http.c
index e74d051..f461e5d 100644
--- a/dirmngr/http.c
+++ b/dirmngr/http.c
@@ -31,7 +31,7 @@
  */
 
 /* Simple HTTP client implementation.  We try to keep the code as
-   self-contained as possible.  There are some contraints however:
+   self-contained as possible.  There are some constraints however:
 
   - estream is required.  We now require estream because it provides a
     very useful and portable asprintf implementation and the fopencookie
@@ -1347,7 +1347,7 @@ do_parse_uri (parsed_uri_t uri, int only_local_part,
 	  if ((n = remove_escapes (uri->host)) < 0)
 	    return GPG_ERR_BAD_URI;
 	  if (n != strlen (uri->host))
-	    return GPG_ERR_BAD_URI;	/* Hostname incudes a Nul. */
+	    return GPG_ERR_BAD_URI;	/* Hostname includes a Nul. */
 	  p = p2 ? p2 : NULL;
 	}
       else if (uri->is_http)
@@ -2185,7 +2185,7 @@ store_header (http_t hd, char *line)
   if (*line == ' ' || *line == '\t')
     {
       /* Continuation. This won't happen too often as it is not
-         recommended.  We use a straightforward implementaion. */
+         recommended.  We use a straightforward implementation. */
       if (!hd->headers)
         return GPG_ERR_PROTOCOL_VIOLATION;
       n += strlen (hd->headers->value);
@@ -2468,7 +2468,7 @@ start_server ()
 
 /* Return true if SOCKS shall be used.  This is the case if tor_mode
  * is enabled and the desired address is not the loopback address.
- * This function is basically a copy of the same internal fucntion in
+ * This function is basically a copy of the same internal function in
  * Libassuan.  */
 static int
 use_socks (struct sockaddr_storage *addr)
diff --git a/dirmngr/ldap-wrapper.c b/dirmngr/ldap-wrapper.c
index ac4964a..8b53bd6 100644
--- a/dirmngr/ldap-wrapper.c
+++ b/dirmngr/ldap-wrapper.c
@@ -107,7 +107,7 @@ struct wrapper_context_s
 
 
 
-/* We keep a global list of spawed wrapper process.  A separate thread
+/* We keep a global list of spawned wrapper process.  A separate thread
    makes use of this list to log error messages and to watch out for
    finished processes. */
 static struct wrapper_context_s *wrapper_list;
diff --git a/dirmngr/loadswdb.c b/dirmngr/loadswdb.c
index 5a7778d..7791f68 100644
--- a/dirmngr/loadswdb.c
+++ b/dirmngr/loadswdb.c
@@ -32,7 +32,7 @@
 
 /* Get the time from the current swdb file and store it at R_FILEDATE
  * and R_VERIFIED.  If the file does not exist 0 is stored at there.
- * The function returns 0 on sucess or an error code.  */
+ * The function returns 0 on success or an error code.  */
 static gpg_error_t
 time_of_saved_swdb (const char *fname, time_t *r_filedate, time_t *r_verified)
 {
@@ -59,7 +59,7 @@ time_of_saved_swdb (const char *fname, time_t *r_filedate, time_t *r_verified)
       goto leave;
     }
 
-  /* Note that the parser uses the first occurance of a matching
+  /* Note that the parser uses the first occurrence of a matching
    * values and ignores possible duplicated values.  */
   maxlen = 2048; /* Set limit.  */
   while ((len = es_read_line (fp, &line, &length_of_line, &maxlen)) > 0)
diff --git a/dirmngr/server.c b/dirmngr/server.c
index f4aeadb..237cb52 100644
--- a/dirmngr/server.c
+++ b/dirmngr/server.c
@@ -1413,7 +1413,7 @@ lookup_cert_by_pattern (assuan_context_t ctx, char *line,
         }
     }
 
-  /* First look through the internal cache.  The certifcates returned
+  /* First look through the internal cache.  The certificates returned
      here are not counted towards the truncation limit.  */
   if (single && !cache_only)
     ; /* Do not read from the local cache in this case.  */
@@ -1940,7 +1940,7 @@ ensure_keyserver (ctrl_t ctrl)
         }
     }
 
-  /* Decide which to use.  Note that the sesssion has no keyservers
+  /* Decide which to use.  Note that the session has no keyservers
      yet set. */
   if (onion_items && !onion_items->next && plain_items && !plain_items->next)
     {
@@ -2328,7 +2328,7 @@ cmd_ks_put (assuan_context_t ctx, char *line)
     }
 
   /* Ask for the key meta data. Not actually needed for HKP servers
-     but we do it anyway to test the client implementaion.  */
+     but we do it anyway to test the client implementation.  */
   err = assuan_inquire (ctx, "KEYBLOCK_INFO",
                         &info, &infolen, MAX_KEYBLOCK_LENGTH);
   if (err)
diff --git a/doc/HACKING b/doc/HACKING
index fc0c3f4..62a6f95 100644
--- a/doc/HACKING
+++ b/doc/HACKING
@@ -348,7 +348,7 @@ Note that such a comment will be removed if the git commit option
   - g10/mdfilter.c :: Filter to calculate hashs
   - g10/textfilter.c :: Filter to handle CR/LF and trailing white space
   - g10/cipher.c   :: En-/Decryption filter
-  - g10/misc.c     :: Utlity functions
+  - g10/misc.c     :: Utility functions
   - g10/options.h  :: Structure with all the command line options
                       and related constants
   - g10/openfile.c :: Create/Open Files
@@ -358,7 +358,7 @@ Note that such a comment will be removed if the git commit option
 
   - g10/pubkey-enc.c :: Process a public key encoded packet.
   - g10/seckey-cert.c :: Not anymore used
-  - g10/seskey.c     :: Make sesssion keys etc.
+  - g10/seskey.c     :: Make session keys etc.
   - g10/import.c     :: Import keys into our key storage.
   - g10/export.c     :: Export keys to the OpenPGP format.
   - g10/sign.c       :: Create signature and optionally encrypt.
diff --git a/doc/dirmngr.texi b/doc/dirmngr.texi
index 027bb94..22a7943 100644
--- a/doc/dirmngr.texi
+++ b/doc/dirmngr.texi
@@ -1141,7 +1141,7 @@ as a binary blob.
 @c recursive process because a CRL has to be checked for each certificate
 @c in the chain except for the root certificate, of which we already know
 @c that it is trusted and we avoid checking a CRL here due to common
- at c setup problems and the assumption that a revoked root certifcate has
+ at c setup problems and the assumption that a revoked root certificate has
 @c been removed from the list of trusted certificates.
 @c
 @c
diff --git a/doc/gpg-agent.texi b/doc/gpg-agent.texi
index 6aab646..edcdf1a 100644
--- a/doc/gpg-agent.texi
+++ b/doc/gpg-agent.texi
@@ -1323,7 +1323,7 @@ This command adds a passphrase to the cache for the specified @var{keygrip}.
   PRESET_PASSPHRASE [--inquire] <string_or_keygrip> <timeout> [<hexstring>]
 @end example
 
-The passphrase is a hexidecimal string when specified. When not specified, the
+The passphrase is a hexadecimal string when specified. When not specified, the
 passphrase will be retrieved from the pinentry module unless the
 @option{--inquire} option was specified in which case the passphrase will be
 retrieved from the client.
diff --git a/doc/gpgsm.texi b/doc/gpgsm.texi
index 1d00839..c3f5aac 100644
--- a/doc/gpgsm.texi
+++ b/doc/gpgsm.texi
@@ -1564,8 +1564,8 @@ to @var{value}.
 This option overrides the command line option
 @option{--include-certs}.  A @var{value} of -2 includes all
 certificates except for the root certificate, -1 includes all
-certicates, 0 does not include any certicates, 1 includes only the
-signers certicate and all other positive values include up to
+certificates, 0 does not include any certificates, 1 includes only the
+signers certificate and all other positive values include up to
 @var{value} certificates starting with the signer cert.
 
 @item list-mode
diff --git a/g10/call-agent.c b/g10/call-agent.c
index 0ba9787..be8c33d 100644
--- a/g10/call-agent.c
+++ b/g10/call-agent.c
@@ -758,7 +758,7 @@ agent_keytocard (const char *hexgrip, int keyno, int force,
 

 /* Call the agent to retrieve a data object.  This function returns
    the data in the same structure as used by the learn command.  It is
-   allowed to update such a structure using this commmand. */
+   allowed to update such a structure using this command. */
 int
 agent_scd_getattr (const char *name, struct agent_card_info_s *info)
 {
diff --git a/g10/getkey.c b/g10/getkey.c
index 75b8564..d8c81c9 100644
--- a/g10/getkey.c
+++ b/g10/getkey.c
@@ -368,7 +368,7 @@ cache_user_id (KBNODE keyblock)
 
 /* Disable and drop the public key cache (which is filled by
    cache_public_key and get_pubkey).  Note: there is currently no way
-   to reenable this cache.  */
+   to re-enable this cache.  */
 void
 getkey_disable_caches ()
 {
@@ -413,7 +413,7 @@ pubkeys_free (pubkey_t keys)
     }
 }
 
-/* Returns all keys that match the search specfication SEARCH_TERMS.
+/* Returns all keys that match the search specification SEARCH_TERMS.
 
    This function also checks for and warns about duplicate entries in
    the keydb, which can occur if the user has configured multiple
diff --git a/g10/gpg.c b/g10/gpg.c
index d193cb2..ecddb20 100644
--- a/g10/gpg.c
+++ b/g10/gpg.c
@@ -2110,7 +2110,7 @@ parse_compliance_option (const char *string)
 
 
 
-/* Helper to set compliance related options.  This is a separte
+/* Helper to set compliance related options.  This is a separate
  * function so that it can also be used by the --compliance option
  * parser.  */
 static void
diff --git a/g10/import.c b/g10/import.c
index ba1c44a..a942c2e 100644
--- a/g10/import.c
+++ b/g10/import.c
@@ -755,7 +755,7 @@ valid_keyblock_packet (int pkttype)
 /****************
  * Read the next keyblock from stream A.
  * Meta data (ring trust packets) are only considered of WITH_META is set.
- * PENDING_PKT should be initialzed to NULL and not changed by the caller.
+ * PENDING_PKT should be initialized to NULL and not changed by the caller.
  * Return: 0 = okay, -1 no more blocks or another errorcode.
  *         The int at at R_V3KEY counts the number of unsupported v3
  *         keyblocks.
@@ -2681,7 +2681,7 @@ chk_self_sigs (ctrl_t ctrl, kbnode_t keyblock, u32 *keyid, int *non_self)
 
 
 /* Delete all parts which are invalid and those signatures whose
- * public key algorithm is not available in this implemenation; but
+ * public key algorithm is not available in this implementation; but
  * consider RSA as valid, because parse/build_packets knows about it.
  *
  * Returns: True if at least one valid user-id is left over.
diff --git a/g10/keydb.h b/g10/keydb.h
index 7f42738..1da93a7 100644
--- a/g10/keydb.h
+++ b/g10/keydb.h
@@ -109,7 +109,7 @@ struct pubkey_find_info {
 };
 
 
-/* Helper type for preference fucntions. */
+/* Helper type for preference functions. */
 union pref_hint
 {
   int digest_length;
@@ -301,7 +301,7 @@ void pubkey_free (pubkey_t key);
 /* Free a list of public keys.  */
 void pubkeys_free (pubkey_t keys);
 
-/* Returns all keys that match the search specfication SEARCH_TERMS.
+/* Returns all keys that match the search specification SEARCH_TERMS.
    The returned keys should be freed using pubkeys_free.  */
 gpg_error_t
 get_pubkeys (ctrl_t ctrl,
diff --git a/g10/keyedit.c b/g10/keyedit.c
index a7a5f72..ba08d88 100644
--- a/g10/keyedit.c
+++ b/g10/keyedit.c
@@ -1593,7 +1593,7 @@ sign_uids (ctrl_t ctrl, estream_t fp,
 	continue;
 
       /* Now we can sign the user ids.  */
-    reloop:  /* (Must use this, because we are modifing the list.)  */
+    reloop:  /* (Must use this, because we are modifying the list.)  */
       primary_pk = NULL;
       for (node = keyblock; node; node = node->next)
 	{
@@ -4104,7 +4104,7 @@ show_key_with_all_names (ctrl_t ctrl, estream_t fp,
               && pk->seckey_info->is_protected
               && pk->seckey_info->s2k.mode == 1002)
 	    {
-              /* FIXME: Check wether this code path is still used.  */
+              /* FIXME: Check whether this code path is still used.  */
 	      tty_fprintf (fp, "%*s%s", opt.legacy_list_mode? 21:5, "",
                            _("card-no: "));
 	      if (pk->seckey_info->ivlen == 16
@@ -6361,7 +6361,7 @@ menu_revsig (ctrl_t ctrl, kbnode_t keyblock)
     }
 
   /* now we can sign the user ids */
-reloop:			/* (must use this, because we are modifing the list) */
+reloop:			/* (must use this, because we are modifying the list) */
   primary_pk = keyblock->pkt->pkt.public_key;
   for (node = keyblock; node; node = node->next)
     {
@@ -6641,7 +6641,7 @@ menu_revsubkey (ctrl_t ctrl, kbnode_t pub_keyblock)
   if (!reason)
       return 0; /* User decided to cancel.  */
 
- reloop: /* (better this way because we are modifing the keyring) */
+ reloop: /* (better this way because we are modifying the keyring) */
   mainpk = pub_keyblock->pkt->pkt.public_key;
   for (node = pub_keyblock; node; node = node->next)
     {
diff --git a/g10/keylist.c b/g10/keylist.c
index c75856f..e2b8fef 100644
--- a/g10/keylist.c
+++ b/g10/keylist.c
@@ -596,7 +596,7 @@ list_one (ctrl_t ctrl, strlist_t names, int secret, int mark_secret)
     listctx.check_sigs = 1;
 
   /* fixme: using the bynames function has the disadvantage that we
-   * don't know wether one of the names given was not found.  OTOH,
+   * don't know whether one of the names given was not found.  OTOH,
    * this function has the advantage to list the names in the
    * sequence as defined by the keyDB and does not duplicate
    * outputs.  A solution could be do test whether all given have
diff --git a/g10/openfile.c b/g10/openfile.c
index 2257107..80d86cf 100644
--- a/g10/openfile.c
+++ b/g10/openfile.c
@@ -127,7 +127,7 @@ make_outfile_name (const char *iname)
 
 /* Ask for an output filename; use the given one as default.  Return
    NULL if no file has been given or if it is not possible to ask the
-   user.  NAME is the template len which might conatin enbedded Nuls.
+   user.  NAME is the template len which might contain enbedded Nuls.
    NAMELEN is its actual length.
  */
 char *
diff --git a/g10/packet.h b/g10/packet.h
index 3cb1e3b..a10495c 100644
--- a/g10/packet.h
+++ b/g10/packet.h
@@ -492,7 +492,7 @@ typedef struct {
  * implementation defined.  GnuPG uses this to cache signature
  * verification status and since 2.1.18 also to convey information
  * about the origin of a key.  Note that this packet is not part
- * struct packet_struct becuase we use it only local in the packet
+ * struct packet_struct because we use it only local in the packet
  * parser and builder. */
 typedef struct {
   unsigned int trustval;
diff --git a/g10/seskey.c b/g10/seskey.c
index 8617938..1549017 100644
--- a/g10/seskey.c
+++ b/g10/seskey.c
@@ -1,4 +1,4 @@
-/* seskey.c -  make sesssion keys etc.
+/* seskey.c -  make session keys etc.
  * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004,
  *               2006, 2009, 2010 Free Software Foundation, Inc.
  *
@@ -311,7 +311,7 @@ encode_md_value (PKT_public_key *pk, gcry_md_hd_t md, int hash_algo)
 
 
       /* ECDSA 521 is special has it is larger than the largest hash
-         we have (SHA-512).  Thus we chnage the size for further
+         we have (SHA-512).  Thus we change the size for further
          processing to 512.  */
       if (pk->pubkey_algo == PUBKEY_ALGO_ECDSA && qbits > 512)
         qbits = 512;
diff --git a/g10/tdbio.c b/g10/tdbio.c
index c780789..7572b9a 100644
--- a/g10/tdbio.c
+++ b/g10/tdbio.c
@@ -1707,7 +1707,7 @@ tdbio_delete_record (ctrl_t ctrl, ulong recnum)
   if (rc)
     return rc;
 
-  /* Now we can chnage it to a free record.  */
+  /* Now we can change it to a free record.  */
   rc = tdbio_read_record (0, &vr, RECTYPE_VER);
   if (rc)
     log_fatal (_("%s: error reading version record: %s\n"),
diff --git a/g10/tofu.c b/g10/tofu.c
index 7bef27b..1437a50 100644
--- a/g10/tofu.c
+++ b/g10/tofu.c
@@ -1941,7 +1941,7 @@ ask_about_binding (ctrl_t ctrl,
   /* I think showing the large message once is sufficient.  If we
    * would move it right before the cpr_get many lines will scroll
    * away and the user might not realize that he merely entered a
-   * wrong choise (because he does not see that either).  As a small
+   * wrong choice (because he does not see that either).  As a small
    * benefit we allow C-L to redisplay everything.  */
   tty_printf ("%s", prompt);
 
@@ -2239,7 +2239,7 @@ build_conflict_set (ctrl_t ctrl, tofu_dbs_t dbs,
     if (!die)
       {
         /*err = gpg_error_from_syserror ();*/
-        xoutofcore (); /* Fixme: Let the fucntion return an error.  */
+        xoutofcore (); /* Fixme: Let the function return an error.  */
       }
 
     for (i = 0; i < conflict_set_count; i ++)
diff --git a/g10/trustdb.c b/g10/trustdb.c
index f8a0bc9..e2c3bda 100644
--- a/g10/trustdb.c
+++ b/g10/trustdb.c
@@ -1512,7 +1512,7 @@ sanitize_regexp(const char *old)
 
   /* There are basically two commonly-used regexps here.  GPG and most
      versions of PGP use "<[^>]+[@.]example\.com>$" and PGP (9)
-     command line uses "example.com" (i.e. whatever the user specfies,
+     command line uses "example.com" (i.e. whatever the user specifies,
      and we can't expect users know to use "\." instead of ".").  So
      here are the rules: we're allowed to start with "<[^>]+[@.]" and
      end with ">$" or start and end with nothing.  In between, the
diff --git a/g10/verify.c b/g10/verify.c
index 4399f71..caeb1a2 100644
--- a/g10/verify.c
+++ b/g10/verify.c
@@ -60,7 +60,7 @@ verify_signatures (ctrl_t ctrl, int nfiles, char **files )
     /* Decide whether we should handle a detached or a normal signature,
      * which is needed so that the code later can hash the correct data and
      * not have a normal signature act as detached signature and ignoring the
-     * indended signed material from the 2nd file or stdin.
+     * intended signed material from the 2nd file or stdin.
      * 1. gpg <file        - normal
      * 2. gpg file         - normal (or detached)
      * 3. gpg file <file2  - detached
diff --git a/g13/backend.c b/g13/backend.c
index 0123b45..835c66b 100644
--- a/g13/backend.c
+++ b/g13/backend.c
@@ -105,7 +105,7 @@ be_take_lock_for_create (ctrl_t ctrl, const char *fname, dotlock_t *r_lock)
   *r_lock = NULL;
 
   /* A DM-crypt container requires special treatment by using the
-     syshelper fucntions.  */
+     syshelper functions.  */
   if (ctrl->conttype == CONTTYPE_DM_CRYPT)
     {
       /*  */
diff --git a/g13/create.c b/g13/create.c
index d55b859..d773dfa 100644
--- a/g13/create.c
+++ b/g13/create.c
@@ -217,7 +217,7 @@ write_keyblob (const char *filename,
 
 
 
-/* Create a new container under the name FILENAME and intialize it
+/* Create a new container under the name FILENAME and initialize it
    using the current settings.  If the file already exists an error is
    returned.  */
 gpg_error_t
diff --git a/g13/g13-common.h b/g13/g13-common.h
index 1fe80d3..acf25b8 100644
--- a/g13/g13-common.h
+++ b/g13/g13-common.h
@@ -61,7 +61,7 @@ struct
   const char *agent_program;
 
   /* Filename of the GPG program.  Unless set via an program option it
-     is initialzed at the first engine startup to the standard gpg
+     is initialized at the first engine startup to the standard gpg
      filename.  */
   const char *gpg_program;
 
diff --git a/kbx/keybox-blob.c b/kbx/keybox-blob.c
index 82f1cfe..6874212 100644
--- a/kbx/keybox-blob.c
+++ b/kbx/keybox-blob.c
@@ -65,7 +65,7 @@
            1 = The only defined value
    - u16  Blob flags
           bit 0 = contains secret key material (not used)
-          bit 1 = ephemeral blob (e.g. used while quering external resources)
+          bit 1 = ephemeral blob (e.g. used while querying external resources)
    - u32  Offset to the OpenPGP keyblock or the X.509 DER encoded
           certificate
    - u32  The length of the keyblock or certificate
@@ -229,7 +229,7 @@ struct keyboxblob {
 
 
 

-/* A simple implemention of a dynamic buffer.  Use init_membuf() to
+/* A simple implementation of a dynamic buffer.  Use init_membuf() to
    create a buffer, put_membuf to append bytes and get_membuf to
    release and return the buffer.  Allocation errors are detected but
    only returned at the final get_membuf(), this helps not to clutter
diff --git a/kbx/keybox-defs.h b/kbx/keybox-defs.h
index 154d4fc..fd331f1 100644
--- a/kbx/keybox-defs.h
+++ b/kbx/keybox-defs.h
@@ -33,7 +33,7 @@
 
 #include <sys/types.h> /* off_t */
 
-/* We include the type defintions from jnlib instead of defining our
+/* We include the type definitions from jnlib instead of defining our
    owns here.  This will not allow us build KBX in a standalone way
    but there is currently no need for it anyway.  Same goes for
    stringhelp.h which for example provides a replacement for stpcpy -
diff --git a/kbx/keybox-openpgp.c b/kbx/keybox-openpgp.c
index d82c2cb..0ba0b9a 100644
--- a/kbx/keybox-openpgp.c
+++ b/kbx/keybox-openpgp.c
@@ -296,7 +296,7 @@ parse_key (const unsigned char *data, size_t datalen,
     }
   else
     {
-      /* Its a pitty that we need to prefix the buffer with the tag
+      /* Its a pity that we need to prefix the buffer with the tag
          and a length header: We can't simply pass it to the fast
          hashing function for that reason.  It might be a good idea to
          have a scatter-gather enabled hash function. What we do here
diff --git a/m4/lib-link.m4 b/m4/lib-link.m4
index e3d26fc..9bdaffa 100644
--- a/m4/lib-link.m4
+++ b/m4/lib-link.m4
@@ -173,7 +173,7 @@ AC_DEFUN([AC_LIB_LINKFLAGS_BODY],
     fi
 ])
   dnl Search the library and its dependencies in $additional_libdir and
-  dnl $LDFLAGS. Using breadth-first-seach.
+  dnl $LDFLAGS. Using breadth-first-search.
   LIB[]NAME=
   LTLIB[]NAME=
   INC[]NAME=
diff --git a/m4/po.m4 b/m4/po.m4
index 201c7ca..354981d 100644
--- a/m4/po.m4
+++ b/m4/po.m4
@@ -129,12 +129,12 @@ changequote([,])dnl
               test -n "$as_me" && echo "$as_me: setting ALL_LINGUAS in configure.in is obsolete" || echo "setting ALL_LINGUAS in configure.in is obsolete"
             fi
             ALL_LINGUAS_=`sed -e "/^#/d" -e "s/#.*//" "$ac_given_srcdir/$ac_dir/LINGUAS"`
-            # Hide the ALL_LINGUAS assigment from automake < 1.5.
+            # Hide the ALL_LINGUAS assignment from automake < 1.5.
             eval 'ALL_LINGUAS''=$ALL_LINGUAS_'
             POMAKEFILEDEPS="$POMAKEFILEDEPS LINGUAS"
           else
             # The set of available languages was given in configure.in.
-            # Hide the ALL_LINGUAS assigment from automake < 1.5.
+            # Hide the ALL_LINGUAS assignment from automake < 1.5.
             eval 'ALL_LINGUAS''=$OBSOLETE_ALL_LINGUAS'
           fi
           # Compute POFILES
@@ -315,7 +315,7 @@ changequote([,])dnl
     sed_x_LINGUAS=`$gt_echo "$sed_x_variable" | sed -e '/^ *#/d' -e 's/VARIABLE/LINGUAS/g'`
     ALL_LINGUAS_=`sed -n -e "$sed_x_LINGUAS" < "$ac_file"`
   fi
-  # Hide the ALL_LINGUAS assigment from automake < 1.5.
+  # Hide the ALL_LINGUAS assignment from automake < 1.5.
   eval 'ALL_LINGUAS''=$ALL_LINGUAS_'
   # Compute POFILES
   # as      $(foreach lang, $(ALL_LINGUAS), $(srcdir)/$(lang).po)
diff --git a/scd/apdu.c b/scd/apdu.c
index 65f770d..97624eb 100644
--- a/scd/apdu.c
+++ b/scd/apdu.c
@@ -94,7 +94,7 @@ struct reader_table_s {
   int used;            /* True if slot is used. */
   unsigned short port; /* Port number:  0 = unused, 1 - dev/tty */
 
-  /* Function pointers intialized to the various backends.  */
+  /* Function pointers initialized to the various backends.  */
   int (*connect_card)(int);
   int (*disconnect_card)(int);
   int (*close_reader)(int);
@@ -230,7 +230,7 @@ static npth_mutex_t reader_table_lock;
 #define PCSC_E_SERVICE_STOPPED         0x8010001E
 #define PCSC_W_REMOVED_CARD            0x80100069
 
-/* Fix pcsc-lite ABI incompatibilty.  */
+/* Fix pcsc-lite ABI incompatibility.  */
 #ifndef SCARD_CTL_CODE
 #ifdef _WIN32
 #include <winioctl.h>
diff --git a/scd/app.c b/scd/app.c
index 044bb1d..ec04b40 100644
--- a/scd/app.c
+++ b/scd/app.c
@@ -99,7 +99,7 @@ app_dump_state (void)
   npth_mutex_unlock (&app_list_lock);
 }
 
-/* Check wether the application NAME is allowed.  This does not mean
+/* Check whether the application NAME is allowed.  This does not mean
    we have support for it though.  */
 static int
 is_app_allowed (const char *name)
@@ -939,7 +939,7 @@ app_change_pin (app_t app, ctrl_t ctrl, const char *chvnostr, int reset_mode,
 
 
 /* Perform a VERIFY operation without doing anything lese.  This may
-   be used to initialze a the PIN cache for long lasting other
+   be used to initialize a the PIN cache for long lasting other
    operations.  Its use is highly application dependent. */
 gpg_error_t
 app_check_pin (app_t app, ctrl_t ctrl, const char *keyidstr,
diff --git a/scd/atr.c b/scd/atr.c
index 9dc79de..4f5a3b8 100644
--- a/scd/atr.c
+++ b/scd/atr.c
@@ -1,4 +1,4 @@
-/* atr.c - ISO 7816 ATR fucntions
+/* atr.c - ISO 7816 ATR functions
  * Copyright (C) 2003, 2011 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
diff --git a/scd/command.c b/scd/command.c
index 56fdf74..6bcbce4 100644
--- a/scd/command.c
+++ b/scd/command.c
@@ -445,7 +445,7 @@ cmd_learn (assuan_context_t ctx, char *line)
               xfree (serial);
               return rc;
             }
-          /* Not canceled, so we have to proceeed.  */
+          /* Not canceled, so we have to proceed.  */
         }
       xfree (serial);
     }
diff --git a/scd/iso7816.c b/scd/iso7816.c
index d146bd0..081b080 100644
--- a/scd/iso7816.c
+++ b/scd/iso7816.c
@@ -204,7 +204,7 @@ iso7816_list_directory (int slot, int list_dirs,
 }
 
 
-/* This funcion sends an already formatted APDU to the card.  With
+/* This function sends an already formatted APDU to the card.  With
    HANDLE_MORE set to true a MORE DATA status will be handled
    internally.  The return value is a gpg error code (i.e. a mapped
    status word).  This is basically the same as apdu_send_direct but
diff --git a/sm/import.c b/sm/import.c
index c7b65ad..8796cd2 100644
--- a/sm/import.c
+++ b/sm/import.c
@@ -814,7 +814,7 @@ parse_p12 (ctrl_t ctrl, ksba_reader_t reader, struct stats_s *stats)
 /*    print_mpi ("   q", sk.q); */
 /*    print_mpi ("   u", sk.u); */
 
-  /* Create an S-expresion from the parameters. */
+  /* Create an S-expression from the parameters. */
   err = gcry_sexp_build (&s_key, NULL,
                          "(private-key(rsa(n%m)(e%m)(d%m)(p%m)(q%m)(u%m)))",
                          sk.n, sk.e, sk.d, sk.p, sk.q, sk.u, NULL);
diff --git a/sm/keylist.c b/sm/keylist.c
index 1b1a261..13de45d 100644
--- a/sm/keylist.c
+++ b/sm/keylist.c
@@ -79,7 +79,7 @@ struct
 
 
 /* Do not print this extension in the list of extensions.  This is set
-   for oids which are already available via ksba fucntions. */
+   for oids which are already available via ksba functions. */
 #define OID_FLAG_SKIP 1
 /* The extension is a simple UTF8String and should be printed.  */
 #define OID_FLAG_UTF8 2
diff --git a/sm/misc.c b/sm/misc.c
index 1e2465f..6d04776 100644
--- a/sm/misc.c
+++ b/sm/misc.c
@@ -1,4 +1,4 @@
-/* misc.c - Miscellaneous fucntions
+/* misc.c - Miscellaneous functions
  * Copyright (C) 2004, 2009, 2011 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
diff --git a/sm/qualified.c b/sm/qualified.c
index 718141e..564e779 100644
--- a/sm/qualified.c
+++ b/sm/qualified.c
@@ -32,7 +32,7 @@
 
 /* We open the file only once and keep the open file pointer as well
    as the name of the file here.  Note that, a listname not equal to
-   NULL indicates that this module has been intialized and if the
+   NULL indicates that this module has been initialized and if the
    LISTFP is also NULL, no list of qualified signatures exists. */
 static char *listname;
 static FILE *listfp;
diff --git a/sm/server.c b/sm/server.c
index 37d66e2..64a3add 100644
--- a/sm/server.c
+++ b/sm/server.c
@@ -409,7 +409,7 @@ cmd_signer (assuan_context_t ctx, char *line)
     {
       gpgsm_status2 (ctrl, STATUS_INV_SGNR,
                      get_inv_recpsgnr_code (rc), line, NULL);
-      /* For compatibiliy reasons we also issue the old code after the
+      /* For compatibility reasons we also issue the old code after the
          new one.  */
       gpgsm_status2 (ctrl, STATUS_INV_RECP,
                      get_inv_recpsgnr_code (rc), line, NULL);
diff --git a/sm/sign.c b/sm/sign.c
index a153b51..e65562d 100644
--- a/sm/sign.c
+++ b/sm/sign.c
@@ -391,7 +391,7 @@ gpgsm_sign (ctrl_t ctrl, certlist_t signerlist,
           goto leave;
         }
 
-      /* Although we don't check for ambigious specification we will
+      /* Although we don't check for ambiguous specification we will
          check that the signer's certificate is usable and valid.  */
       rc = gpgsm_cert_use_sign_p (cert);
       if (!rc)
diff --git a/tests/gpgscm/tests.scm b/tests/gpgscm/tests.scm
index 3118977..c6c887f 100644
--- a/tests/gpgscm/tests.scm
+++ b/tests/gpgscm/tests.scm
@@ -236,7 +236,7 @@
 ;; (letfd <bindings> <body>)
 ;;
 ;; Bind all variables given in <bindings> and initialize each of them
-;; to the given initial value, and close them after evaluting <body>.
+;; to the given initial value, and close them after evaluating <body>.
 (define-macro (letfd bindings . body)
   (let bind ((bindings' bindings))
     (if (null? bindings')
@@ -305,7 +305,7 @@
 ;;
 ;; Bind all variables given in <bindings>, initialize each of them to
 ;; a string representing an unique path in the filesystem, and delete
-;; them after evaluting <body>.
+;; them after evaluating <body>.
 (define-macro (lettmp bindings . body)
   (let bind ((bindings' bindings))
     (if (null? bindings')
diff --git a/tests/inittests b/tests/inittests
index 1a51bdf..6fbccfb 100755
--- a/tests/inittests
+++ b/tests/inittests
@@ -65,10 +65,10 @@ fi
 echo gnupg-test-directory > testdir.stamp
 
 
-# Create the private key directy if it does not exists and copy 
+# Create the private key directly if it does not exists and copy
 # the sample keys.
 [ -d private-keys-v1.d ] || mkdir private-keys-v1.d
-for i in ${private_keys}; do 
+for i in ${private_keys}; do
     cat ${srcdir}/samplekeys/$i.key >private-keys-v1.d/$i.key
 done
 
@@ -94,6 +94,6 @@ EOF
 
 # Make sure that the sample certs are available but ignore errors here
 # because we are not a test script.
-for i in ${sample_certs}; do 
+for i in ${sample_certs}; do
     $GPGSM --import ${srcdir}/samplekeys/$i || true
 done
diff --git a/tests/openpgp/bug537-test.data.asc b/tests/openpgp/bug537-test.data.asc
index 130dd5b..b6b02e9 100644
--- a/tests/openpgp/bug537-test.data.asc
+++ b/tests/openpgp/bug537-test.data.asc
@@ -1,5 +1,5 @@
 This is a binary (gzip compressed) file which exhibits a problem with
-the zlib decryptor.  See encr-data.c:decrypt_data for a decription of
+the zlib decryptor.  See encr-data.c:decrypt_data for a description of
 the problem we solved with 1.9.92 (1.4.6).  It is not easy to produce
 such files, but this one works.  The source file is also in the BTS
 under the name check-data-410-1.data.  The result of the decryption
diff --git a/tests/openpgp/quick-key-manipulation.scm b/tests/openpgp/quick-key-manipulation.scm
index 8d14ae1..c21abfe 100755
--- a/tests/openpgp/quick-key-manipulation.scm
+++ b/tests/openpgp/quick-key-manipulation.scm
@@ -79,7 +79,7 @@
 ;; XXX I don't know how to verify this.  The keylisting does not seem
 ;; to indicate the primary UID.
 
-(info "Checking that we get an error making non-existant user ID the primary one.")
+(info "Checking that we get an error making non-existent user ID the primary one.")
 (catch '()
        (call-check `(, at GPG --quick-set-primary-uid ,(exact alpha) ,charlie))
        (error "Expected an error, but get none."))
@@ -87,7 +87,7 @@
 (info "Checking that we can revoke a user ID...")
 (call-check `(, at GPG --quick-revoke-uid ,(exact bravo) ,alpha))
 
-(info "Checking that we get an error revoking a non-existant user ID.")
+(info "Checking that we get an error revoking a non-existent user ID.")
 (catch '()
        (call-check `(, at GPG --quick-revoke-uid ,(exact bravo) ,charlie))
        (error "Expected an error, but get none."))
diff --git a/tests/pkits/README b/tests/pkits/README
index 17f03ea..06aa97b 100644
--- a/tests/pkits/README
+++ b/tests/pkits/README
@@ -7,7 +7,7 @@ http://csrc.nist.gov/pki/testing/x509paths.html .
 README             - this file.
 PKITS_data.tar.bz2 - the original ZIP file, repackaged as a tarball.
 Makefile.am        - Part of our build system.
-import-all-certs   - Run a simple import test on all certifcates
+import-all-certs   - Run a simple import test on all certificates
 validate-all-certs - Run an import and validate test on all certificates
 signature-verification         - PKITS test 4.1  
 validity-periods               - PKITS test 4.2  
diff --git a/tools/gpg-connect-agent.c b/tools/gpg-connect-agent.c
index f20d331..00482a3 100644
--- a/tools/gpg-connect-agent.c
+++ b/tools/gpg-connect-agent.c
@@ -839,7 +839,7 @@ add_definq (char *line, int is_var, int is_prog)
 }
 
 
-/* Show all inquiry defintions. */
+/* Show all inquiry definitions. */
 static void
 show_definq (void)
 {
diff --git a/tools/gpgconf-comp.c b/tools/gpgconf-comp.c
index 0ef3cb4..f608f7a 100644
--- a/tools/gpgconf-comp.c
+++ b/tools/gpgconf-comp.c
@@ -1389,7 +1389,7 @@ gc_component_reload (int component)
 

 /* More or less Robust version of dgettext.  It has the side effect of
    switching the codeset to utf-8 because this is what we want to
-   output.  In theory it is posible to keep the original code set and
+   output.  In theory it is possible to keep the original code set and
    switch back for regular disgnostic output (redefine "_(" for that)
    but given the natur of this tool, being something invoked from
    other pograms, it does not make much sense.  */
diff --git a/tools/gpgconf.c b/tools/gpgconf.c
index d6bf9a2..2236555 100644
--- a/tools/gpgconf.c
+++ b/tools/gpgconf.c
@@ -329,7 +329,7 @@ query_swdb (estream_t out, const char *name, const char *current_version)
       goto leave;
     }
 
-  /* Note that the parser uses the first occurance of a matching
+  /* Note that the parser uses the first occurrence of a matching
    * values and ignores possible duplicated values.  */
 
   maxlen = 2048; /* Set limit.  */
diff --git a/tools/mail-signed-keys b/tools/mail-signed-keys
index 3c564f1..263b8e5 100755
--- a/tools/mail-signed-keys
+++ b/tools/mail-signed-keys
@@ -9,7 +9,7 @@
 # WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
 # implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
-# FIXME: Use only valid email addreses, extract only given keys
+# FIXME: Use only valid email addresses, extract only given keys
 
 dryrun=0
 if [ "$1" = "--dry-run" ]; then
diff --git a/tools/symcryptrun.c b/tools/symcryptrun.c
index 563e56b..54976ca 100644
--- a/tools/symcryptrun.c
+++ b/tools/symcryptrun.c
@@ -432,7 +432,7 @@ confucius_copy_file (char *infile, char *outfile, int plain)
 /* Get a passphrase in secure storage (if possible).  If AGAIN is
    true, then this is a repeated attempt.  If CANCELED is not a null
    pointer, it will be set to true or false, depending on if the user
-   canceled the operation or not.  On error (including cancelation), a
+   canceled the operation or not.  On error (including cancellation), a
    null pointer is returned.  The passphrase must be deallocated with
    confucius_drop_pass.  CACHEID is the ID to be used for passphrase
    caching and can be NULL to disable caching.  */
diff --git a/tools/watchgnupg.c b/tools/watchgnupg.c
index f8b6fdc..fc58d14 100644
--- a/tools/watchgnupg.c
+++ b/tools/watchgnupg.c
@@ -446,7 +446,7 @@ main (int argc, char **argv)
       client_t client;
 
       /* Usually we don't have that many connections, thus it is okay
-         to set them allways from scratch and don't maintain an active
+         to set them always from scratch and don't maintain an active
          fd_set. */
       FD_ZERO (&rfds);
       max_fd = -1;
diff --git a/tools/wks-util.c b/tools/wks-util.c
index d78e01d..8eab834 100644
--- a/tools/wks-util.c
+++ b/tools/wks-util.c
@@ -1,4 +1,4 @@
-/* wks-utils.c - Common helper fucntions for wks tools
+/* wks-utils.c - Common helper functions for wks tools
  * Copyright (C) 2016 g10 Code GmbH
  *
  * This file is part of GnuPG.

-----------------------------------------------------------------------

Summary of changes:
 agent/call-pinentry.c                    |  6 +++---
 agent/call-scd.c                         |  4 ++--
 agent/command-ssh.c                      |  4 ++--
 agent/findkey.c                          |  2 +-
 agent/pkdecrypt.c                        |  2 +-
 agent/pksign.c                           |  2 +-
 agent/trustlist.c                        |  2 +-
 build-aux/texinfo.tex                    | 10 +++++-----
 common/ChangeLog-2011.include            |  2 +-
 common/audit.c                           |  2 +-
 common/call-gpg.c                        |  2 +-
 common/dotlock.c                         |  2 +-
 common/exechelp.h                        |  4 ++--
 common/exectool.c                        |  2 +-
 common/init.h                            |  2 +-
 common/openpgp-oid.c                     |  2 +-
 common/recsel.c                          |  2 +-
 common/sexputil.c                        |  4 ++--
 common/simple-pwquery.h                  |  2 +-
 common/sysutils.c                        |  2 +-
 common/t-session-env.c                   |  2 +-
 configure.ac                             |  6 +++---
 dirmngr/certcache.c                      |  2 +-
 dirmngr/dns-stuff.c                      |  2 +-
 dirmngr/dns-stuff.h                      |  2 +-
 dirmngr/dns.c                            |  2 +-
 dirmngr/http.c                           |  8 ++++----
 dirmngr/ldap-wrapper.c                   |  2 +-
 dirmngr/loadswdb.c                       |  4 ++--
 dirmngr/server.c                         |  6 +++---
 dirmngr/validate.c                       |  6 +++---
 doc/HACKING                              |  4 ++--
 doc/dirmngr.texi                         |  2 +-
 doc/gpg-agent.texi                       |  2 +-
 doc/gpgsm.texi                           |  4 ++--
 g10/call-agent.c                         |  2 +-
 g10/getkey.c                             |  4 ++--
 g10/gpg.c                                |  2 +-
 g10/import.c                             |  4 ++--
 g10/keydb.h                              |  4 ++--
 g10/keyedit.c                            |  8 ++++----
 g10/keylist.c                            |  2 +-
 g10/openfile.c                           |  2 +-
 g10/packet.h                             |  2 +-
 g10/seskey.c                             |  4 ++--
 g10/tdbio.c                              |  2 +-
 g10/tofu.c                               |  4 ++--
 g10/trustdb.c                            |  2 +-
 g10/verify.c                             |  2 +-
 g13/backend.c                            |  2 +-
 g13/create.c                             |  2 +-
 g13/g13-common.h                         |  2 +-
 kbx/keybox-blob.c                        |  4 ++--
 kbx/keybox-defs.h                        |  2 +-
 kbx/keybox-openpgp.c                     |  2 +-
 m4/lib-link.m4                           |  2 +-
 m4/po.m4                                 |  6 +++---
 scd/apdu.c                               |  4 ++--
 scd/app-openpgp.c                        |  4 ++--
 scd/app.c                                |  4 ++--
 scd/atr.c                                |  2 +-
 scd/command.c                            |  2 +-
 scd/iso7816.c                            |  2 +-
 sm/certlist.c                            |  4 ++--
 sm/import.c                              |  2 +-
 sm/keylist.c                             |  2 +-
 sm/misc.c                                |  2 +-
 sm/qualified.c                           |  2 +-
 sm/server.c                              |  2 +-
 sm/sign.c                                |  2 +-
 tests/gpgscm/tests.scm                   |  4 ++--
 tests/inittests                          |  6 +++---
 tests/openpgp/bug537-test.data.asc       |  2 +-
 tests/openpgp/quick-key-manipulation.scm |  4 ++--
 tests/pkits/README                       |  2 +-
 tools/gpg-connect-agent.c                |  2 +-
 tools/gpgconf-comp.c                     |  2 +-
 tools/gpgconf.c                          |  2 +-
 tools/mail-signed-keys                   |  2 +-
 tools/symcryptrun.c                      |  2 +-
 tools/watchgnupg.c                       |  2 +-
 tools/wks-util.c                         |  2 +-
 82 files changed, 123 insertions(+), 123 deletions(-)


hooks/post-receive
diff --git a/dirmngr/validate.c b/dirmngr/validate.c
index 3671a8b..371852b 100644
--- a/dirmngr/validate.c
+++ b/dirmngr/validate.c
@@ -147,7 +147,7 @@ unknown_criticals (ksba_cert_t cert)
         }
     }
   if (err && gpg_err_code (err) != GPG_ERR_EOF)
-    rc = err; /* Such an error takes precendence.  */
+    rc = err; /* Such an error takes precedence.  */
 
   return rc;
 }
@@ -344,7 +344,7 @@ is_root_cert (ksba_cert_t cert, const char *issuerdn, const char *subjectdn)
     {
       if (gpg_err_code (err) == GPG_ERR_NO_DATA)
         return 1; /* Yes. Without a authorityKeyIdentifier this needs
-                     to be the Root certifcate (our trust anchor).  */
+                     to be the Root certificate (our trust anchor).  */
       log_error ("error getting authorityKeyIdentifier: %s\n",
                  gpg_strerror (err));
       return 0; /* Well, it is broken anyway.  Return No. */
@@ -619,7 +619,7 @@ validate_cert_chain (ctrl_t ctrl, ksba_cert_t cert, ksba_isotime_t r_exptime,
                 log_info ("root certificate is good and trusted\n");
             }
 
-          break;  /* Okay: a self-signed certicate is an end-point. */
+          break;  /* Okay: a self-signed certificate is an end-point. */
         }
 
       /* To avoid loops, we use an arbitrary limit on the length of
diff --git a/scd/app-openpgp.c b/scd/app-openpgp.c
index 66b235d..25f3dbe 100644
--- a/scd/app-openpgp.c
+++ b/scd/app-openpgp.c
@@ -1588,7 +1588,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
 }
 
 
 /* Get the public key for KEYNO and store it as an S-expresion with
    the APP handle.  On error that field gets cleared.  If we already
    know about the public key we will just return.  Note that this does
    not mean a key is available; this is solely indicated by the
@@ -1596,7 +1596,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
 
    Note that GnuPG 1.x does not need this and it would be too time
    consuming to send it just for the fun of it. However, given that we
-   use the same code in gpg 1.4, we can't use the gcry S-expresion
+   use the same code in gpg 1.4, we can't use the gcry S-expression
    here but need to open encode it. */
 #if GNUPG_MAJOR_VERSION > 1
 static gpg_error_t
@@ -1588,7 +1588,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
 
 
-/* Get the public key for KEYNO and store it as an S-expresion with
+/* Get the public key for KEYNO and store it as an S-expression with
    the APP handle.  On error that field gets cleared.  If we already
    know about the public key we will just return.  Note that this does
diff --git a/sm/certlist.c b/sm/certlist.c
index e493cda..39ab03c 100644
--- a/sm/certlist.c
+++ b/sm/certlist.c
@@ -388,7 +388,7 @@ gpgsm_add_to_certlist (ctrl_t ctrl, const char *name, int secret,
                   if (!dup_certs)
                     gpgsm_add_cert_to_certlist (ctrl, cert, &dup_certs, 0);
 
                   /* We have to ignore ambigious names as long as
                      there only fault is a bad key usage.  This is
                      required to support encryption and signing
                      certificates of the same subject.
@@ -532,7 +532,7 @@ gpgsm_find_cert (ctrl_t ctrl,
             }
 
           /* If we don't have the KEYID filter we need to check for
-             ambigious search results.  Note, that it is somehwat
+             ambiguous search results.  Note, that it is somehwat
              reasonable to assume that a specification of a KEYID
              won't lead to ambiguous names. */
           if (!rc && !keyid)
@@ -388,7 +388,7 @@ gpgsm_add_to_certlist (ctrl_t ctrl, const char *name, int secret,
                     gpgsm_add_cert_to_certlist (ctrl, cert, &dup_certs, 0);
 
-                  /* We have to ignore ambigious names as long as
+                  /* We have to ignore ambiguous names as long as
                      there only fault is a bad key usage.  This is
                      required to support encryption and signing
-- 
The GNU Privacy Guard
http://git.gnupg.org




More information about the Gnupg-commits mailing list